import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:equatable/equatable.dart';

class EmpresaEntity extends Equatable {
  final String uuid;
  final bool activo;
  final String adminNombre;
  final String adminApellido;
  final String email;
  final DateTime fechaAlta;
  final DateTime fechaVto;
  final String empNombre;
  final String telefono;
  final bool caravanas;
  final bool potreros;
  final bool feedlot;
  final String cuig;
  final int tolerancia;
  final int toleranciaRemanente;
  final bool balancearDieta;

  EmpresaEntity(
      this.uuid,
      this.activo,
      this.adminNombre,
      this.adminApellido,
      this.email,
      this.fechaAlta,
      this.fechaVto,
      this.empNombre,
      this.telefono,
      this.caravanas,
//    Si tiene activo el módulo de potrero, debe pedir los datos.
      this.potreros,
//    Si tiene activo el módulo de feedlot(al momento de crear una tropa tiene la obligación de ingresar los datos de materia seca y gdpv), debe pedir los datos.
      this.feedlot,
      this.cuig,
      this.tolerancia,
      this.toleranciaRemanente,
      this.balancearDieta);

  Map<String, Object> toJson() {
    return {
      'activo': this.activo,
      'adminNombre': this.adminNombre,
      'adminApellido': this.adminApellido,
      'email': this.email,
      'fechaAlta': this.fechaAlta,
      'fechaVto': this.fechaVto,
      'empNombre': this.empNombre,
      'telefono': this.telefono,
      'caravanas': this.caravanas,
      'potreros': this.potreros,
      'feedlot': this.feedlot,
      'cuig': this.cuig,
      'tolerancia': this.tolerancia,
      'toleranciaRemanente': this.toleranciaRemanente,
      'balancearDieta': this.balancearDieta
    };
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      super == other &&
          other is EmpresaEntity &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          activo == other.activo &&
          adminNombre == other.adminNombre &&
          adminApellido == other.adminApellido &&
          email == other.email &&
          fechaAlta == other.fechaAlta &&
          fechaVto == other.fechaVto &&
          empNombre == other.empNombre &&
          telefono == other.telefono &&
          caravanas == other.caravanas &&
          potreros == other.potreros &&
          feedlot == other.feedlot &&
          cuig == other.cuig &&
          tolerancia == other.tolerancia &&
          toleranciaRemanente == other.toleranciaRemanente &&
          balancearDieta == other.balancearDieta;

  @override
  int get hashCode =>
      super.hashCode ^
      uuid.hashCode ^
      activo.hashCode ^
      adminNombre.hashCode ^
      adminApellido.hashCode ^
      email.hashCode ^
      fechaAlta.hashCode ^
      fechaVto.hashCode ^
      empNombre.hashCode ^
      telefono.hashCode ^
      caravanas.hashCode ^
      potreros.hashCode ^
      feedlot.hashCode ^
      cuig.hashCode ^
      tolerancia.hashCode ^
      toleranciaRemanente.hashCode ^
      balancearDieta.hashCode;

  @override
  String toString() {
    return 'EmpresaEntity{uuid: $uuid, activo: $activo, adminNombre: $adminNombre, adminApellido: $adminApellido, email: $email, fechaAlta: $fechaAlta, fechaVto: $fechaVto, empNombre: $empNombre, telefono: $telefono, caravanas: $caravanas, potreros: $potreros, feedlot: $feedlot, cuig: $cuig, tolerancia: $tolerancia, toleranciaRemanente: $toleranciaRemanente, balancearDieta: $balancearDieta}';
  }

  static EmpresaEntity fromJson(Map<String, Object> json) {
    return EmpresaEntity(
        json["uuid"] as String,
        json["activo"] as bool,
        json["adminNombre"] as String,
        json["adminApellido"] as String,
        json["email"] as String,
        json["fechaAlta"] as DateTime,
        json["fechaVto"] as DateTime,
        json["empNombre"] as String,
        json["telefono"] as String,
        json["caravanas"] as bool,
        json["potreros"] as bool,
        json["feedlot"] as bool,
        json["cuig"] as String,
        json['tolerancia'] as int,
        json['toleranciaRemanente'] as int,
        json['balancearDieta'] as bool);
  }

  EmpresaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : uuid = snapshot.documentID,
        activo = snapshot.data['activo'],
        adminNombre = snapshot.data['adminNombre'],
        adminApellido = snapshot.data['adminApellido'],
        email = snapshot.data['email'],
        fechaAlta = snapshot.data['fechaAlta'] != null
            ? snapshot.data['fechaAlta'] is int
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['fechaAlta'].round().toInt())
                : snapshot.data['fechaAlta'] is DateTime
                    ? snapshot.data['fechaAlta']
                    : snapshot.data['fechaAlta'].toDate()
            : DateTime.now(),
        fechaVto = snapshot.data['fechaVto'] != null
            ? snapshot.data['fechaVto'] is int
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['fechaVto'].round().toInt())
                : snapshot.data['fechaVto'] is DateTime
                    ? snapshot.data['fechaVto']
                    : snapshot.data['fechaVto'].toDate()
            : DateTime.now(),
        empNombre = snapshot.data['nombre'],
        telefono = snapshot.data['tel'],
        caravanas = snapshot.data['caravanas'],
        potreros = snapshot.data['potreros'],
        feedlot = snapshot.data['feedlot'],
        cuig = snapshot.data['cuig'],
        balancearDieta = snapshot.data['balancearDieta'] ?? false,
        tolerancia = snapshot.data['tolerancia'] != null
            ? snapshot.data['tolerancia'] is int
                ? snapshot.data['tolerancia']
                : snapshot.data['tolerancia'].toInt()
            : 0,
        toleranciaRemanente = snapshot.data['tolerancia_remanente'] != null
            ? snapshot.data['tolerancia_remanente'] is int
                ? snapshot.data['tolerancia_remanente']
                : snapshot.data['tolerancia_remanente'].toInt()
            : 0;

  Map<String, Object> toDocument() {
    return {
      "activo": activo,
      "adminNombre": adminNombre,
      "adminApellido": adminApellido,
      "email": email,
      "fechaAlta": fechaAlta,
      "fechaVto": fechaVto,
      "empNombre": empNombre,
      "telefono": telefono,
      "caravanas": caravanas,
      "potreros": potreros,
      "feedlot": feedlot,
      "cuig": cuig,
      'tolerancia': tolerancia,
      'toleranciaRemanente': toleranciaRemanente,
      'balancearDieta': balancearDieta,
    };
  }
}
