import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'cargas_repository.dart';
import 'entities/entities.dart';

class FirebaseCargasRepository implements CargaRepository {
  CollectionReference cargasCollection;
  String empresaId;
  String usuarioId;

  FirebaseCargasRepository({@required String empresaId, @required String usuarioId}) {
    this.cargasCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("cargas");
  }

  @override
  Future<void> addNewCarga(Carga carga) {
    return cargasCollection.add(carga.copyWith(usuarioUuid: this.usuarioId).toEntity().toDocument());
  }

  @override
  Future<void> deleteCarga(Carga carga) async {
    return cargasCollection.document(carga.uuid).delete();
  }

  @override
  Stream<List<Carga>> cargas() {
    return cargasCollection.where("usuario", isEqualTo: this.usuarioId)
        .where("activo", isEqualTo: true).snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((car) => Carga.fromEntity(CargaEntity.fromSnapshot(car))).toList();
    });
  }

  @override
  Future<void> updateCarga(Carga update) {
    return cargasCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }

}
