import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'categorias_repository.dart';
import 'entities/entities.dart';

class FirebaseCategoriasRepository implements CategoriasRepository {
  CollectionReference categoriasCollection;
  String empresaId;

  FirebaseCategoriasRepository(
      {@required String empresaId}) {
    this.categoriasCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("categorias");
  }

  @override
  Future<void> addNewCategoria(Categoria categoria) {
    return categoriasCollection.add(categoria.toEntity().toDocument());
  }

  @override
  Future<void> deleteCategoria(Categoria categoria) async {
    return categoriasCollection.document(categoria.uuid).delete();
  }

  @override
  Stream<List<Categoria>> categorias() {
    return categoriasCollection
        .snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Categoria.fromEntity(CategoriaEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateCategoria(Categoria update) {
    return categoriasCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }
}
