import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'categorias_sanitarias_repository.dart';
import 'entities/entities.dart';

class FirebaseCategoriasSanitariasRepository implements CategoriasSanitariasRepository {
  CollectionReference categoriaSanitariaCollection;
  String empresaId;

  FirebaseCategoriasSanitariasRepository(
      {@required String empresaId}) {
    this.categoriaSanitariaCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("categoriassanitarias");
  }

  @override
  Future<void> addNewCategoriaSanitaria(CategoriaSanitaria categoriaSanitaria) {
    return categoriaSanitariaCollection.add(categoriaSanitaria.toEntity().toDocument());
  }

  @override
  Future<void> deleteCategoriaSanitaria(CategoriaSanitaria categoriaSanitaria) async {
    return categoriaSanitariaCollection.document(categoriaSanitaria.uuid).delete();
  }

  @override
  Stream<List<CategoriaSanitaria>> categoriasSanitarias() {
    return categoriaSanitariaCollection.snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => CategoriaSanitaria.fromEntity(CategoriaSanitariaEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateCategoriaSanitaria(CategoriaSanitaria update) {
    return categoriaSanitariaCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }


}
