import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'entities/entities.dart';

class FirebaseCorralesRepository implements CorralesRepository {
  CollectionReference corralesCollection;
  String empresaId;

  FirebaseCorralesRepository(
      {@required String empresaId}) {
    this.corralesCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("corrales");
  }

  @override
  Future<void> addNewCorral(Corral corral) {
    return corralesCollection.add(corral.toEntity().toDocument());
  }

  @override
  Future<void> deleteCorral(Corral corral) async {
    return corralesCollection.document(corral.uuid).delete();
  }

  @override
  Stream<List<Corral>> corrales() {
    return corralesCollection
        .where("activo", isEqualTo: true).snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Corral.fromEntity(CorralEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateCorral(Corral update) {
    return corralesCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }
}
