import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'dietas_programadas_repository.dart';
import 'entities/entities.dart';

class FirebaseDietasProgramadasRepository implements DietasProgramadasRepository {
  CollectionReference dietasProgramadasCollection;
  String empresaId;

  FirebaseDietasProgramadasRepository(
      {@required String empresaId}) {
    this.dietasProgramadasCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("dietas_programadas");
  }

  @override
  Future<void> addNewDietaProgramada(DietaProgramada dietaProgramada) {
    return dietasProgramadasCollection.add(dietaProgramada.toEntity().toDocument());
  }

  @override
  Future<void> deleteDietaProgramada(DietaProgramada dietaProgramada) async {
    return dietasProgramadasCollection.document(dietaProgramada.uuid).delete();
  }

  @override
  Stream<List<DietaProgramada>> dietasProgramadas() {
    return dietasProgramadasCollection.snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => DietaProgramada.fromEntity(DietaProgramadaEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateDietaProgramada(DietaProgramada update) {
    return dietasProgramadasCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }

}
