import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'dietas_repository.dart';
import 'entities/entities.dart';

class FirebaseDietasRepository implements DietasRepository {
  CollectionReference dietaCollection;
  String empresaId;
  CollectionReference ordenCollection;

  FirebaseDietasRepository(
      {@required String empresaId}) {
    this.dietaCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("dietas");
  }

  @override
  Future<void> addNewDieta(Dieta dieta) {
    return dietaCollection.add(dieta.toEntity().toDocument());
  }

  @override
  Future<void> deleteDieta(Dieta dieta) async {
    return dietaCollection.document(dieta.uuid).delete();
  }

  @override
  Stream<List<Dieta>> dietas() {
    return dietaCollection
        .where("activo", isEqualTo: true).snapshots().map((snapshot) {
      print(snapshot);

      return snapshot.documents
          .map((doc) => Dieta.fromEntity(DietaEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateDieta(Dieta update) {
    return dietaCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }


}
