import 'dart:async';
import 'dart:typed_data';
import 'package:flutter_bluetooth_serial_caravanas/flutter_bluetooth_serial.dart';
import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_repository/src/dispositivos_repository.dart';

import 'entities/entities.dart';
import 'models/models.dart';

class FirebaseDispositivosRepository implements DispositivosRepository {
  CollectionReference dispositivoCollection;
  String usuarioId;
  List<BluetoothDevice> listBlue;
  BluetoothConnection _connection;

  FirebaseDispositivosRepository(
      {@required String empresaId, @required this.usuarioId}) {
    this.dispositivoCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection('dispositivos');
  }

  @override
  Future<void> addNewDispositivo(Dispositivo dipositivo) {
    return dispositivoCollection.add(dipositivo
        .copyWith(profileUuid: this.usuarioId, baston: "", monitor: "")
        .toEntity()
        .toDocument());
  }

  @override
  Future<void> deleteDispositivo(Dispositivo dispositivo) {
    return dispositivoCollection.document(dispositivo.uuid).delete();
  }

  @override
  Stream<Dispositivo> dipositivo() {
    return dispositivoCollection
        .where("profileUuid", isEqualTo: this.usuarioId)
        .snapshots()
        .map((snap) {
      print(snap);
      if (snap.documents.isEmpty) {
        var disp = Dispositivo(
            profileUuid: this.usuarioId, baston: "", monitor: "");
        dispositivoCollection.add(disp
            .toEntity()
            .toDocument());
        return disp;
      } else {
        return Dispositivo.fromEntity(
            DispositivoEntity.fromSnapshot(snap.documents.first));
      }
    });
  }

  @override
  enable() {
    FlutterBluetoothSerial.instance.requestEnable();
  }

  @override
  disable() {
    FlutterBluetoothSerial.instance.requestDisable();
  }

  @override
  Future<void> updateDispositivo(Dispositivo update) {
    return dispositivoCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }

  @override
  Future<String> listenDevice(String address) async {
    var mensaje;
    BluetoothConnection
        .toAddress(address)
        .then((connection) {
      _connection = connection;
      connection.input.listen((data) =>  mensaje = _onDataReceived(data));
    });

    return mensaje;
  }


  @override
  void dispose() {
    _connection.dispose();
  }

  String _onDataReceived(Uint8List data) {
    String _messageBuffer = '';
    // Allocate buffer for parsed data
    int backspacesCounter = 0;
    data.forEach((byte) {
      if (byte == 8 || byte == 127) {
        backspacesCounter++;
      }
    });
    Uint8List buffer = Uint8List(data.length - backspacesCounter);
    int bufferIndex = buffer.length;

    // Apply backspace control character
    backspacesCounter = 0;
    for (int i = data.length - 1; i >= 0; i--) {
      if (data[i] == 8 || data[i] == 127) {
        backspacesCounter++;
      } else {
        if (backspacesCounter > 0) {
          backspacesCounter--;
        } else {
          buffer[--bufferIndex] = data[i];
        }
      }
    }

    // Create message if there is new line character
    String dataString = String.fromCharCodes(buffer);
    int index = buffer.indexOf(13);
    if (~index != 0) {
      // \r\n

      //
      _messageBuffer = backspacesCounter > 0
          ? _messageBuffer.substring(
          0, _messageBuffer.length - backspacesCounter)
          : _messageBuffer + dataString.substring(0, index);

      print("1 :" + _messageBuffer);

      _messageBuffer = _messageBuffer.replaceAll("\n", "");
      _messageBuffer = dataString.substring(index + 1);
      return _messageBuffer.substring(8);
    } else {
      _messageBuffer = (backspacesCounter > 0
          ? _messageBuffer.substring(
          0, _messageBuffer.length - backspacesCounter)
          : _messageBuffer + dataString);

      print("2 :" + _messageBuffer);

      _messageBuffer = _messageBuffer.replaceAll("\n", "");
      _messageBuffer = dataString.substring(index + 1);
//    return _messageBuffer;
    }
  }
}
