import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'entities/entities.dart';
import 'mixers_repository.dart';

class FirebaseMixersRepository implements MixersRepository {
  CollectionReference mixerCollection;
  String empresaId;

  FirebaseMixersRepository(
      {@required String empresaId}) {
    this.mixerCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("mixers");
  }

  @override
  Future<void> addNewMixer(Mixer mixer) {
    return mixerCollection.add(mixer.toEntity().toDocument());
  }

  @override
  Future<void> deleteMixer(Mixer mixer) async {
    return mixerCollection.document(mixer.uuid).delete();
  }

  @override
  Stream<List<Mixer>> mixers() {
    return mixerCollection
        .where("activo", isEqualTo: true).snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Mixer.fromEntity(MixerEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateMixer(Mixer update) {
    return mixerCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }


}
