import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'entities/entities.dart';

class FirebasePendientesRepository implements PendientesRepository {
  CollectionReference pendienteCollection;
  String usuarioId;

  FirebasePendientesRepository(
      {@required String empresaId, @required this.usuarioId}) {

    this.pendienteCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("pendientes");
  }

  @override
  Future<void> addNewPendiente(Pendiente pendiente) {

    return pendienteCollection.add(pendiente.copyWith(usuarioUid: this.usuarioId).toEntity().toDocument());
  }

  @override
  Future<void> deletePendiente(Pendiente pendiente) async {
    return pendienteCollection.document(pendiente.uuid).delete();
  }

  @override
  Stream<List<Pendiente>> pendientes() {
    return pendienteCollection.where("usuarioUid", isEqualTo: this.usuarioId)
        .where("activo", isEqualTo: true).snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Pendiente.fromEntity(PendienteEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updatePendiente(Pendiente update) {
    return pendienteCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }
}
