import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'entities/entities.dart';
import 'productos_repository.dart';

class FirebaseProductosRepository implements ProductosRepository {
  CollectionReference productoCollection;
  String empresaId;

  FirebaseProductosRepository(
      {@required String empresaId}) {
    this.productoCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("productos");
  }

  @override
  Future<void> addNewProducto(Producto producto) {
    return productoCollection.add(producto.toEntity().toDocument());
  }

  @override
  Future<void> deleteProducto(Producto producto) async {
    return productoCollection.document(producto.uuid).delete();
  }

  @override
  Stream<List<Producto>> productos() {
    return productoCollection
        .where("activo", isEqualTo: true).snapshots().map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Producto.fromEntity(ProductoEntity.fromSnapshot(doc))).toList();
    });
  }

  @override
  Future<void> updateProducto(Producto update) {
    return productoCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }


}
