import 'dart:async';

import 'package:meta/meta.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../firebase_repository.dart';
import 'tercero_repository.dart';
import 'entities/entities.dart';
import 'tercero_repository.dart';

class FirebaseTercerosRepository implements TercerosRepository {
  CollectionReference tercerosCollection;
  String empresaId;

  FirebaseTercerosRepository({@required String empresaId}) {
    this.tercerosCollection = Firestore.instance
        .collection('empresas')
        .document(empresaId)
        .collection("terceros");
  }

  @override
  Future<void> addNewTercero(Tercero tercero) {
    return tercerosCollection.add(tercero.toEntity().toDocument());
  }

  @override
  Future<void> deleteTercero(Tercero tercero) async {
    return tercerosCollection.document(tercero.uuid).delete();
  }

  @override
  Stream<List<Tercero>> terceros() {
    return tercerosCollection
        .where("activo", isEqualTo: true)
        .snapshots()
        .map((snapshot) {
      print(snapshot);
      return snapshot.documents
          .map((doc) => Tercero.fromEntity(TerceroEntity.fromSnapshot(doc)))
          .toList();
    });
  }

  @override
  Future<void> updateTercero(Tercero update) {
    return tercerosCollection
        .document(update.uuid)
        .updateData(update.toEntity().toDocument());
  }
}
