import 'package:meta/meta.dart';
import '../entities/entities.dart';

@immutable
class Producto {
  final String uuid;
  final String nombre;
  final bool activo;
  final double precio;
  final double calcio;
  final double fdn;
  final DateTime fecha;
  final double fosforo;
  final double materia;
  final double mcal;
  final double prot;
  final int minimo;
  final int stock;

  Producto(
      {this.uuid,
      this.nombre,
      this.activo,
      this.precio,
      this.calcio,
      this.fdn,
      this.fecha,
      this.fosforo,
      this.materia,
      this.mcal,
      this.prot,
      this.minimo,
      this.stock});

  Producto copyWith(
      {String uuid,
      String nombre,
      bool activo,
      double precio,
      double calcio,
      double fdn,
      DateTime fecha,
      double fosforo,
      double materia,
      double mcal,
      double prot,
      int minimo,
      int stock}) {
    return Producto(
        uuid: uuid ?? this.uuid,
        nombre: nombre ?? this.nombre,
        activo: activo ?? this.activo,
        precio: precio ?? this.precio,
        calcio: calcio ?? this.calcio,
        fdn: fdn ?? this.fdn,
        fecha: fecha ?? this.fecha,
        fosforo: fosforo ?? this.fosforo,
        materia: materia ?? this.materia,
        mcal: mcal ?? this.mcal,
        prot: prot ?? this.prot,
        minimo: minimo ?? this.minimo,
        stock: stock ?? this.stock);
  }

  @override
  String toString() {
    return 'Producto{uuid: $uuid, nombre: $nombre, activo: $activo, precio: $precio, calcio: $calcio, fdn: $fdn, fecha: $fecha, fosforo: $fosforo, materia: $materia, mcal: $mcal, prot: $prot, minimo: $minimo, stock: $stock}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is Producto &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          nombre == other.nombre &&
          activo == other.activo &&
          precio == other.precio &&
          calcio == other.calcio &&
          fdn == other.fdn &&
          fecha == other.fecha &&
          fosforo == other.fosforo &&
          materia == other.materia &&
          mcal == other.mcal &&
          prot == other.prot &&
          minimo == other.minimo &&
          stock == other.stock;

  @override
  int get hashCode =>
      uuid.hashCode ^
      nombre.hashCode ^
      activo.hashCode ^
      precio.hashCode ^
      calcio.hashCode ^
      fdn.hashCode ^
      fecha.hashCode ^
      fosforo.hashCode ^
      materia.hashCode ^
      mcal.hashCode ^
      prot.hashCode ^
      minimo.hashCode ^
      stock.hashCode;

  ProductoEntity toEntity() {
    return ProductoEntity(uuid, nombre, activo, precio, calcio, fdn, fecha,
        fosforo, materia, mcal, prot, minimo, stock);
  }

  static Producto fromEntity(ProductoEntity entity){
    return Producto(
      uuid: entity.uuid,
      minimo: entity.minimo,
      mcal: entity.mcal,
      materia: entity.materia,
      fosforo: entity.fosforo,
      fecha: entity.fecha,
      calcio: entity.calcio,
      precio: entity.precio,
      activo: entity.activo,
      nombre: entity.nombre,
      fdn: entity.fdn,
      prot: entity.prot,
      stock: entity.stock
    );
  }
}
