import 'package:meta/meta.dart';
import '../entities/entities.dart';

@immutable
class Profile {
  final String uuid;
  final String nombre;
  final String apellido;
  final bool activo;
  final String email;
  final String empresa;
  final String mixer;
  final String rol;
  final bool suspended;

  Profile({
    this.uuid,
    this.nombre,
    this.apellido,
    this.activo,
    this.email,
    this.empresa,
    this.mixer,
    this.rol,
    this.suspended,
  });

  Profile copyWith({
    String uuid,
    String nombre,
    String apellido,
    bool activo,
    String email,
    String empresa,
    String mixer,
    String rol,
    bool suspended,
  }) {
    return Profile(
      uuid: uuid ?? this.uuid,
      nombre: nombre ?? this.nombre,
      apellido: apellido ?? this.apellido,
      activo: activo ?? this.activo,
      email: email ?? this.email,
      empresa: empresa ?? this.empresa,
      mixer: mixer ?? this.mixer,
      rol: rol ?? this.rol,
      suspended: suspended ?? this.suspended,
    );
  }

  @override
  String toString() {
    return 'Profile{uuid: $uuid, nombre: $nombre, apellido: $apellido, activo: $activo, email: $email, empresa: $empresa, mixer: $mixer, rol: $rol, suspended: $suspended}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is Profile &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          nombre == other.nombre &&
          apellido == other.apellido &&
          activo == other.activo &&
          email == other.email &&
          empresa == other.empresa &&
          mixer == other.mixer &&
          rol == other.rol &&
          suspended == other.suspended;

  @override
  int get hashCode =>
      uuid.hashCode ^
      nombre.hashCode ^
      apellido.hashCode ^
      activo.hashCode ^
      email.hashCode ^
      empresa.hashCode ^
      mixer.hashCode ^
      rol.hashCode ^
      suspended.hashCode;

  ProfileEntity toEntity() {
    return ProfileEntity(
        uuid, nombre, apellido, activo, email, empresa, mixer, rol, suspended);
  }

  static Profile fromEntity(ProfileEntity entity) {
    return Profile(
      uuid: entity.uuid,
      nombre: entity.nombre,
      apellido: entity.apellido,
      activo: entity.activo,
      email: entity.email,
      empresa: entity.empresa,
      mixer: entity.mixer,
      rol: entity.rol,
      suspended: entity.suspended,
    );
  }
}
